==> ssleay_0.6.6.orig.tar.gz: ssleay-0.6.6.orig/crypto/x509/x509_set.c <==
/* crypto/x509/x509_set.c */
/* Copyright (C) 1995-1997 Eric Young (eay@mincom.oz.au)
 * All rights reserved.
 *
 * This package is an SSL implementation written
 * by Eric Young (eay@mincom.oz.au).
 * The implementation was written so as to conform with Netscapes SSL.
 * 
 * This library is free for commercial and non-commercial use as long as
 * the following conditions are aheared to.  The following conditions
 * apply to all code found in this distribution, be it the RC4, RSA,
 * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
 * included with this distribution is covered by the same copyright terms
 * except that the holder is Tim Hudson (tjh@mincom.oz.au).
 * 
 * Copyright remains Eric Young's, and as such any Copyright notices in
 * the code are not to be removed.
 * If this package is used in a product, Eric Young should be given attribution
 * as the author of the parts of the library used.
 * This can be in the form of a textual message at program startup or
 * in documentation (online or textual) provided with the package.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *    "This product includes cryptographic software written by
 *     Eric Young (eay@mincom.oz.au)"
 *    The word 'cryptographic' can be left out if the rouines from the library
 *    being used are not cryptographic related :-).
 * 4. If you include any Windows specific code (or a derivative thereof) from 
 *    the apps directory (application code) you must include an acknowledgement:
 *    "This product includes software written by Tim Hudson (tjh@mincom.oz.au)"
 * 
 * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * 
 * The licence and distribution terms for any publically available version or
 * derivative of this code cannot be changed.  i.e. this code cannot simply be
 * copied and put under another distribution licence
 * [including the GNU Public Licence.]
 */

#include <stdio.h>
#include "cryptlib.h"
#include "asn1.h"
#include "objects.h"
#include "envelope.h"
#include "x509.h"

int X509_set_version(x,version)
X509 *x;
long version;
	{
	if (x == NULL) return(0);
	return(ASN1_INTEGER_set(x->cert_info->version,version));
	}

int X509_set_serialNumber(x,serial)
X509 *x;
ASN1_INTEGER *serial;
	{
	ASN1_INTEGER *in;

	if (x == NULL) return(0);
	in=x->cert_info->serialNumber;
	if (in != serial)
		{
		in=ASN1_INTEGER_dup(serial);
		if (in != NULL)
			{
			ASN1_INTEGER_free(x->cert_info->serialNumber);
			x->cert_info->serialNumber=in;
			}
		}
	return(in != NULL);
	}

int X509_set_issuer_name(x,name)
X509 *x;
X509_NAME *name;
	{
	X509_NAME *in;

	if (x == NULL) return(0);
	in=x->cert_info->issuer;
	if (in != name)
		{
		in=X509_NAME_dup(name);
		if (in != NULL)
			{
			X509_NAME_free(x->cert_info->issuer);
			x->cert_info->issuer=in;
			}
		}
	return(in != NULL);
	}

int X509_set_subject_name(x,name)
X509 *x;
X509_NAME *name;
	{
	X509_NAME *in;

	if (x == NULL) return(0);
	in=x->cert_info->subject;
	if (in != name)
		{
		in=X509_NAME_dup(name);
		if (in != NULL)
			{
			X509_NAME_free(x->cert_info->subject);
			x->cert_info->subject=in;
			}
		}
	return(in != NULL);
	}

int X509_set_notBefore(x,tm)
X509 *x;
ASN1_UTCTIME *tm;
	{
	ASN1_UTCTIME *in;

	if ((x == NULL) || (x->cert_info->validity == NULL)) return(0);
	in=x->cert_info->validity->notBefore;
	if (in != tm)
		{
		in=ASN1_UTCTIME_dup(tm);
		if (in != NULL)
			{
			ASN1_UTCTIME_free(x->cert_info->validity->notBefore);
			x->cert_info->validity->notBefore=in;
			}
		}
	return(in != NULL);
	}

int X509_set_notAfter(x,tm)
X509 *x;
ASN1_UTCTIME *tm;
	{
	ASN1_UTCTIME *in;

	if ((x == NULL) || (x->cert_info->validity == NULL)) return(0);
	in=x->cert_info->validity->notAfter;
	if (in != tm)
		{
		in=ASN1_UTCTIME_dup(tm);
		if (in != NULL)
			{
			ASN1_UTCTIME_free(x->cert_info->validity->notAfter);
			x->cert_info->validity->notAfter=in;
			}
		}
	return(in != NULL);
	}

int X509_set_pubkey(x,pkey)
X509 *x;
EVP_PKEY *pkey;
	{
	int ok=0;
	X509_PUBKEY *pk;
	X509_ALGOR *a;
	ASN1_OBJECT *o;
	unsigned char *s,*p;
	int i;

	if (x == NULL) return(0);

	if ((pk=X509_PUBKEY_new()) == NULL) goto err;
	a=pk->algor;

	/* set the algorithm id */
	if ((o=OBJ_nid2obj(pkey->type)) == NULL) goto err;
	ASN1_OBJECT_free(a->algorithm);
	a->algorithm=o;

	/* Set the parameter list */
	if ((a->parameter == NULL) || (a->parameter->type != V_ASN1_NULL))
		{
		ASN1_TYPE_free(a->parameter);
		a->parameter=ASN1_TYPE_new();
		a->parameter->type=V_ASN1_NULL;
		}
	i=i2d_PublicKey(pkey,NULL);
	if ((s=(unsigned char *)Malloc(i+1)) == NULL) goto err;
	p=s;
	i2d_PublicKey(pkey,&p);
	if (!ASN1_BIT_STRING_set(pk->public_key,s,i)) goto err;
	Free(s);

	X509_PUBKEY_free(x->cert_info->key);
	x->cert_info->key=pk;
	pk=NULL;
	ok=1;
err:
	if (pk != NULL) X509_PUBKEY_free(pk);
	return(ok);
	}

==> ssleay_0.8.1.orig.tar.gz: ssleay-0.8.1.orig/crypto/x509/x509_set.c <==
/* crypto/x509/x509_set.c */
/* Copyright (C) 1995-1997 Eric Young (eay@cryptsoft.com)
 * All rights reserved.
 *
 * This package is an SSL implementation written
 * by Eric Young (eay@cryptsoft.com).
 * The implementation was written so as to conform with Netscapes SSL.
 * 
 * This library is free for commercial and non-commercial use as long as
 * the following conditions are aheared to.  The following conditions
 * apply to all code found in this distribution, be it the RC4, RSA,
 * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
 * included with this distribution is covered by the same copyright terms
 * except that the holder is Tim Hudson (tjh@cryptsoft.com).
 * 
 * Copyright remains Eric Young's, and as such any Copyright notices in
 * the code are not to be removed.
 * If this package is used in a product, Eric Young should be given attribution
 * as the author of the parts of the library used.
 * This can be in the form of a textual message at program startup or
 * in documentation (online or textual) provided with the package.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *    "This product includes cryptographic software written by
 *     Eric Young (eay@cryptsoft.com)"
 *    The word 'cryptographic' can be left out if the rouines from the library
 *    being used are not cryptographic related :-).
 * 4. If you include any Windows specific code (or a derivative thereof) from 
 *    the apps directory (application code) you must include an acknowledgement:
 *    "This product includes software written by Tim Hudson (tjh@cryptsoft.com)"
 * 
 * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * 
 * The licence and distribution terms for any publically available version or
 * derivative of this code cannot be changed.  i.e. this code cannot simply be
 * copied and put under another distribution licence
 * [including the GNU Public Licence.]
 */

#include <stdio.h>
#include "cryptlib.h"
#include "asn1.h"
#include "objects.h"
#include "evp.h"
#include "x509.h"

int X509_set_version(x,version)
X509 *x;
long version;
	{
	if (x == NULL) return(0);
	if (x->cert_info->version == NULL)
		{
		if ((x->cert_info->version=ASN1_INTEGER_new()) == NULL)
			return(0);
		}
	return(ASN1_INTEGER_set(x->cert_info->version,version));
	}

int X509_set_serialNumber(x,serial)
X509 *x;
ASN1_INTEGER *serial;
	{
	ASN1_INTEGER *in;

	if (x == NULL) return(0);
	in=x->cert_info->serialNumber;
	if (in != serial)
		{
		in=ASN1_INTEGER_dup(serial);
		if (in != NULL)
			{
			ASN1_INTEGER_free(x->cert_info->serialNumber);
			x->cert_info->serialNumber=in;
			}
		}
	return(in != NULL);
	}

int X509_set_issuer_name(x,name)
X509 *x;
X509_NAME *name;
	{
	if ((x == NULL) || (x->cert_info == NULL)) return(0);
	return(X509_NAME_set(&x->cert_info->issuer,name));
	}

int X509_set_subject_name(x,name)
X509 *x;
X509_NAME *name;
	{
	if ((x == NULL) || (x->cert_info == NULL)) return(0);
	return(X509_NAME_set(&x->cert_info->subject,name));
	}

int X509_set_notBefore(x,tm)
X509 *x;
ASN1_UTCTIME *tm;
	{
	ASN1_UTCTIME *in;

	if ((x == NULL) || (x->cert_info->validity == NULL)) return(0);
	in=x->cert_info->validity->notBefore;
	if (in != tm)
		{
		in=ASN1_UTCTIME_dup(tm);
		if (in != NULL)
			{
			ASN1_UTCTIME_free(x->cert_info->validity->notBefore);
			x->cert_info->validity->notBefore=in;
			}
		}
	return(in != NULL);
	}

int X509_set_notAfter(x,tm)
X509 *x;
ASN1_UTCTIME *tm;
	{
	ASN1_UTCTIME *in;

	if ((x == NULL) || (x->cert_info->validity == NULL)) return(0);
	in=x->cert_info->validity->notAfter;
	if (in != tm)
		{
		in=ASN1_UTCTIME_dup(tm);
		if (in != NULL)
			{
			ASN1_UTCTIME_free(x->cert_info->validity->notAfter);
			x->cert_info->validity->notAfter=in;
			}
		}
	return(in != NULL);
	}

int X509_set_pubkey(x,pkey)
X509 *x;
EVP_PKEY *pkey;
	{
	if ((x == NULL) || (x->cert_info == NULL)) return(0);
	return(X509_PUBKEY_set(&(x->cert_info->key),pkey));
	}
